@@ -8,8 +8,10 @@ from pulpcore.client.pulp_container.api.content_manifests_api import ContentMani
 from pulpcore.client.pulp_container.api.content_signatures_api import ContentSignaturesApi
 from pulpcore.client.pulp_container.api.content_tags_api import ContentTagsApi
 from pulpcore.client.pulp_container.api.distributions_container_api import DistributionsContainerApi
+from pulpcore.client.pulp_container.api.distributions_pull_through_api import DistributionsPullThroughApi
 from pulpcore.client.pulp_container.api.pulp_container_namespaces_api import PulpContainerNamespacesApi
 from pulpcore.client.pulp_container.api.remotes_container_api import RemotesContainerApi
+from pulpcore.client.pulp_container.api.remotes_pull_through_api import RemotesPullThroughApi
 from pulpcore.client.pulp_container.api.repositories_container_api import RepositoriesContainerApi
 from pulpcore.client.pulp_container.api.repositories_container_push_api import RepositoriesContainerPushApi
 from pulpcore.client.pulp_container.api.repositories_container_push_versions_api import RepositoriesContainerPushVersionsApi
